;;; Customised for Emacs 19.30 - CG 24/01/96

;;; pour avoir la date et l'heure sur la modeline
;;; ainsi que l'agenda
(setq display-time-24hr-format t)
(setq display-time-day-and-date t)
(setq display-time-interval 60)
(setq display-time-mail-file t)
(display-time)

;;; highlighter les recherches
(setq query-replace-highlight t)
(setq search-highlight t)

;;; pour camllight
(autoload 'tuareg-mode "tuareg" "Major mode for editing Caml code" t)

;;; y a aucune erreur, donc pas besoin de debugger
(setq debug-on-error nil)

(if (string-lessp emacs-version "19")
    (set-input-mode t t)
  (standard-display-european 1)
  (transient-mark-mode 1)
  (autoload 'accents-mode "accents.el"
    "met les accents" t nil)
  (load-library "paren")
  (global-set-key "%" 'match-paren)
  (defun match-paren (arg)
    "Go to the matching parenthesis if on parenthesis otherwise insert %."
    (interactive "p")
    (cond ((looking-at "\\s\(") (forward-list 1) (backward-char 1))
	  ((looking-at "\\s\)") (forward-char 1) (backward-list 1))
	  ((looking-at "\\s\{") (forward-char 1) (backward-list 1))
	  ((looking-at "\\s\}") (forward-char 1) (backward-list 1))
	  (t (self-insert-command (or arg 1))))))


;;; general background color
(set-background-color "PapayaWhip")
;;; default font color
(set-default-font "-adobe-courier-bold-o-normal--12-*-75-75-m-*-iso8859-1")
;;; pour que les defauts se propagent a toutes les frames
(setq default-frame-alist '(
	  (font . "-adobe-courier-bold-o-normal--12-*-75-75-m-*-iso8859-1")
	  (background-color . "PapayaWhip")))

(set-face-foreground 'default "black")
(set-face-foreground 'bold "black")
(set-face-foreground 'bold-italic "black")
(set-face-foreground 'highlight "firebrick")

;;; syntax highlighting by the font-lock package
;;; mieux que par hilit parce que c'est en temps reel

;;; decoration en temps reel
(add-hook 'findProgramming-file-hooks 'turn-on-font-lock)

;;; le plus de decoration possible
(setq font-lock-maximum-decoration t)

;;; reconnait le type de l'ecran et du background
(require 'font-lock)

(custom-set-variables
  ;; custom-set-variables was added by Custom -- don't edit or cut/paste it!
  ;; Your init file should contain only one such instance.
 '(Info-title-face-alist (quote ((42 bold underline) (61 bold-italic underline) (45 italic underline))))
 '(calendar-today-marker (quote calendar-today-face))
 '(calendar-week-start-day 1)
 '(face-x-resources (quote ((:family (".attributeFamily" . "Face.AttributeFamily")) (:width (".attributeWidth" . "Face.AttributeWidth")) (:height (".attributeHeight" . "Face.AttributeHeight")) (:weight (".attributeWeight" . "Face.AttributeWeight")) (:slant (".attributeSlant" . "Face.AttributeSlant")) (:foreground (".attributeForeground" . "Face.AttributeForeground")) (:overline (".attributeOverline" . "Face.AttributeOverline")) (:strike-through (".attributeStrikeThrough" . "Face.AttributeStrikeThrough")) (:box (".attributeBox" . "Face.AttributeBox")) (:underline (".attributeUnderline" . "Face.AttributeUnderline")) (:inverse-video (".attributeInverse" . "Face.AttributeInverse")) (:stipple (".attributeStipple" . "Face.AttributeStipple") (".attributeBackgroundPixmap" . "Face.AttributeBackgroundPixmap")) (:bold (".attributeBold" . "Face.AttributeBold")) (:italic (".attributeItalic" . "Face.AttributeItalic")) (:font (".attributeFont" . "Face.AttributeFont")) (:inherit (".attributeInherit" . "Face.AttributeInherit")))))
 '(frame-background-mode (quote light))
 '(scroll-bar-mode (quote right))
 '(show-paren-mode t nil (paren))
 '(special-display-frame-alist (quote ((height . 14) (width . 82) (unsplittable . t))))
 '(tool-bar-mode nil nil (tool-bar)))
(custom-set-faces
  ;; custom-set-faces was added by Custom -- don't edit or cut/paste it!
  ;; Your init file should contain only one such instance.
 '(bold ((t (:bold t :underline t :foreground "red"))))
 '(calendar-today-face ((t (:background "green3"))))
 '(font-lock-comment-face ((((class color) (background light)) (:foreground "springgreen4"))))
 '(font-lock-function-name-face ((((class color) (background light)) (:foreground "red3"))))
 '(font-lock-keyword-face ((((class color) (background light)) (:foreground "RoyalBlue"))))
 '(font-lock-reference-face ((((class color) (background light)) (:foreground "firebrick"))))
 '(font-lock-string-face ((((class color) (background light)) (:foreground "DarkGoldenrod"))))
 '(font-lock-type-face ((((class color) (background light)) (:foreground "Purple"))))
 '(font-lock-variable-name-face ((((class color) (background light)) (:foreground "deepskyblue2"))))
 '(info-menu-5 ((t (:underline t :foreground "red3"))))
 '(info-node ((t (:bold t :italic t :underline t :foreground "Blue"))))
 '(info-xref ((t (:bold t :background "green"))))
 '(show-paren-match-face ((t (:background "red")))))

(setq global-font-lock-mode t)


;;; Le mode par defaut est le mode fundamental
(setq default-major-mode 'text-mode)
(setq text-mode-hook 'turn-on-auto-fill)
(setq-default fill-column 80)
(setq case-fold-search t)
(setq line-number-mode t)
(setq accents-mode t)
(display-time)


;;; Determine mode according to filename
(defvar auto-mode-alist nil "\
Alist of filename patterns vs corresponding major mode functions.
Each element looks like (REGEXP . FUNCTION).
Visiting a file whose name matches REGEXP causes FUNCTION to be called.")
(setq auto-mode-alist (mapcar 'purecopy
			      '(("\\.text$" . text-mode)
				("\\.c$" . c-mode)
				("\\.h$" . c-mode)
				("\\.cc$" . c++-mode)
				("\\.hh$" . c++-mode)
				("\\.tex$" . LaTeX-mode)
				("\\.el$" . emacs-lisp-mode)
				("\\.l$" . lisp-mode)
				("\\.lisp$" . lisp-mode)
				("\\.tcl$" . tcl-mode)
				("\\.tk$" . tcl-mode)
				("\\.y$" . bison-mode)
				("\\.p$" . pas-mode)
				("\\.pas$" . pas-mode)
				("\\.tar$" . tar-mode)
;;; Less common extensions come here
;;; so more common ones above are found faster.
				("\\.TeX$" . TeX-mode)
				("\\.sty$" . LaTeX-mode)
				("\\.html$" . html-mode)
				("\\.bbl$" . LaTeX-mode)
				("\\.bib$" . bibtex-mode)
				("\\.article$" . text-mode)
				("\\.letter$" . text-mode)
				("\\.texinfo$" . texinfo-mode)
				("\\.lsp$" . lisp-mode)
				("\\.prolog$" . prolog-mode)
				;; Mailer puts message to be edited in /tmp/Re.... or Message
				("^/tmp/Re" . text-mode)
				;; some news reader is reported to use this
				("^/tmp/fol/" . text-mode)
				("/Message[0-9]*$" . text-mode)
				("\\.cc$" . c-mode)
				("\\.scm.[0-9]*$" . scheme-mode)
				;; in genelex project
				("\\.H$" . c++-mode)
				("\\.C$" . c++-mode)
				;; .emacs following a directory delimiter
				;; in either Unix or VMS syntax.
				("[]>:/]\\..*emacs" . emacs-lisp-mode)
				("RMAIL" . rmail-mode)
				("[Mm]akefile" . makefile-mode)
				("\\.mli$" . tuareg-mode)
				("\\.ml$" . tuareg-mode))))


(put 'eval-expression 'disabled nil)

;;; I find this very usefull (line-to-top-of-window)
(defun line-to-top-of-window ()
  "Scroll the selected window up so that the current line is at the top."
  (interactive)
  (recenter 0))

;;; affectation des touches fonctions
(global-set-key [f1]     'comment-region)             ; F1
(global-set-key [f4]     'font-lock-fontify-buffer)   ; F4
(global-set-key [f5]     'fill-region)                ; F5
(global-set-key [f6]     'next-error)                 ; F6
(global-set-key [f7]     'ispell-region)              ; F7
(global-set-key [f8]     'ispell-buffer)              ; F8
(global-set-key [f9]     'goto-line) 		      ; F9
(global-set-key [f10]    'indent-region)              ; F10
(global-set-key [f35]    'compile)   		      ; F11
(global-set-key [f11]    'compile) 		      ; F11
(global-set-key [f12]    'rmail)                      ; F12

;;; redef de touches sympas
(global-set-key [delete]      'delete-char)
(global-set-key [home]        'beginning-of-line)
(global-set-key [end]         'end-of-line)
(global-set-key [pageup]      'scroll-down)
(global-set-key [pagedown]    'scroll-up)
(global-set-key [C-backspace] 'undo)
(global-set-key "\eg"         'goto-line)
(global-set-key "\C-m"        'newline-and-indent)
(global-set-key "\C-j"        'newline)
(global-set-key "\er"         'replace-string)

;;; Parameters for indented-c++
(setq c-indent-level 3)
(setq c-continued-statement-offset 3)


;;; Automatic creation of a new frame for this buffer types
(setq special-display-buffer-names
      '("*compilation*" "*grep*" "*TeX buffer output*"))

(setq case-replace nil)

;;; correction for english-dired to match french date
(set-variable 'dired-move-to-filename-regexp "\\(Jan\\|Fev\\|Mar\\|Avr\\|Mai\\|Jun\\|Jul\\|Ao.\\|Sep\\|Oct\\|Nov\\|Dec\\)[ ]+[0-9]+ [ 0-9][0-9][:0-9][0-9][ 0-9] ")


;;; rajoute des options dans les menus
(define-key menu-bar-tools-menu [ps-print-buffer-without-faces]
  '("PS Print Buffer Without Faces" . ps-print-buffer))





(put 'upcase-region 'disabled nil)
